@@ -139,7 +139,7 @@ int snd_pcm_loopback_status(snd_pcm_loopback_t *lb, snd_pcm_loopback_status_t *
 {
 	if (!lb)
 		return -EINVAL;
-	if (ioctl(lb->fd, SND_PCM_LB_IOCTL_FORMAT, status) < 0)
+	if (ioctl(lb->fd, SND_PCM_LB_IOCTL_STATUS, status) < 0)
 		return -errno;
 	return 0;
 }
