@@ -301,8 +301,7 @@ static ssize_t linear_transfer(snd_pcm_plugin_t *plugin,
 {
 	struct linear_private_data *data;
 
-	if (plugin == NULL || src_ptr == NULL || src_size < 0 ||
-	                      dst_ptr == NULL || dst_size < 0)
+	if (plugin == NULL || src_ptr == NULL || dst_ptr == NULL)
 		return -EINVAL;
 	if (src_size == 0)
 		return 0;
@@ -370,14 +369,12 @@ int snd_pcm_plugin_build_linear(snd_pcm_format_t *src_format,
 		snd_pcm_format_signed(dst_format->format));
 	src_width = snd_pcm_format_width(src_format->format);
 	dst_width = snd_pcm_format_width(dst_format->format);
-#if __BYTE_ORDER == __LITTLE_ENDIAN
+#ifdef SND_LITTLE_ENDIAN
 	src_endian = snd_pcm_format_big_endian(src_format->format);
 	dst_endian = snd_pcm_format_big_endian(dst_format->format);
-#elif __BYTE_ORDER == __BIG_ENDIAN
+#else
 	src_endian = snd_pcm_format_little_endian(src_format->format);
 	dst_endian = snd_pcm_format_little_endian(dst_format->format);
-#else
-#error "Unsupported endian..."
 #endif
 
 	switch (src_width) {
