@@ -188,7 +188,7 @@ int snd_seq_resize_output_buffer(snd_seq_t *seq, int size)
 {
 	if (!seq || !seq->obuf)
 		return -EINVAL;
-	if (size < sizeof(snd_seq_event_t))
+	if ((size_t)size < sizeof(snd_seq_event_t))
 		return -EINVAL;
 	snd_seq_drain_output(seq);
 	if (size != seq->obufsize) {
@@ -210,7 +210,7 @@ int snd_seq_resize_input_buffer(snd_seq_t *seq, int size)
 {
 	if (!seq || !seq->ibuf)
 		return -EINVAL;
-	if (size < sizeof(snd_seq_event_t))
+	if ((size_t)size < sizeof(snd_seq_event_t))
 		return -EINVAL;
 	snd_seq_drain_input(seq);
 	if (size != seq->ibufsize) {
@@ -857,7 +857,7 @@ static int snd_seq_decode_event(char **buf, int *len, snd_seq_event_t *ev)
 {
 	if (!ev || !buf || !*buf || !len )
 		return -EINVAL;
-	if (*len < sizeof(snd_seq_event_t)) {
+	if ((size_t)*len < sizeof(snd_seq_event_t)) {
 		*len = 0;
 		return -ENOENT;
 	}
