@@ -328,7 +328,7 @@ int decode_event(snd_seq_event_t * ev)
 			
 		case SND_SEQ_EVENT_SYSEX:
 			{
-				unsigned char *sysex = (unsigned char *) ev + sizeof(snd_seq_event_t);
+				unsigned char *sysex = (unsigned char *) ev->data.ext.ptr;
 				int c;
 
 				printf("; len=%d [", ev->data.ext.len);
